pub struct Strategy<'a> {
pub labels: HashMap<String, f64>,
pub freqs: HashMap<String, f64>,
pub a_set: Vec<&'a Link>,
}Expand description
Strategy is the optimal strategy as defined in the Spiess-Florian algorithm.
Fields
labels: HashMap<String, f64>u_{i} - expected travel time from node i to destination
freqs: HashMap<String, f64>f_{i} - combined frequency of attractive links at node i.
f64::INFINITY marks a node whose basket is a single no-wait link.
a_set: Vec<&'a Link>\overline{A} - attractive links forming the hyperpath