Crate hyperpaths_rs

Crate hyperpaths_rs 

Implementation of Spiess, H. and Florian, M. (1989) “Optimal strategies: A new assignment model for transit networks”. See the ref. at spiess_floarian.tex LaTeX file.

Structs

Link
Link is an edge in the transit network graph.
SFResult
SFResult is the result of running through the Spiess-Florian algorithm
Strategy
Strategy is the optimal strategy as defined in the Spiess-Florian algorithm.
Volumes
Volumes holds the assigned demand according to the optimal strategy.

Statics

VERBOSE

Functions

assign_demand
compute_sf
compute_sf computes the Spiess-Florian algorithm
find_optimal_strategy